## Final Project CS107/AC207/CS207
### Group 29
#### Members

1. Tao Tsui
2. Jenny Wang
3. Dashiell Saver-Young
4. Apisada Chulakadabba

Build Status for master branch
[![Build Status m2](https://travis-ci.com/climate-change-is-real-python-dev/cs107-FinalProject.svg?branch=master)](https://travis-ci.com/climate-change-is-real-python-dev/cs107-FinalProject)



CodeCov Badge for master branch
[![codecov](https://codecov.io/gh/climate-change-is-real-python-dev/cs107-FinalProject/branch/master/graph/badge.svg)](https://codecov.io/gh/climate-change-is-real-python-dev/cs107-FinalProject)




### How to install _socialAD_

You can install this open source package by downloading it from pip:

```pip install socialAD```

To get started, in your Python work environment, do:

```import socialAD```

To use the forward mode, do:

```from socialAD.forward import *```
